# SourPea

inspired by <https://github.com/sweetpea-org/>
functions to check counterbalancing of design

This project is in active development by the <a href="https://musslick.github.io/AER_website/Research.html">Autonomous Empirical Research Group</a>
 (package developer: Younes Strittmatter, PI: <a href="https://smusslick.com/">Sebastian Musslick</a>) in collaboration with the <a href="https://ccv.brown.edu/">Center for Computation and Visualization< at Brown University</a>. This research program is supported by Schmidt Science Fellows, in partnership with the Rhodes Trust, as well as the Carney BRAINSTORM program at Brown University.


*heavily under development*